==> goods-center-api-2.8.59-20200907.004611-1-sources.jar: cn/com/duiba/goods/center/api/remoteservice/equity/RemoteEquityGoodsRecordService.java <==
package cn.com.duiba.goods.center.api.remoteservice.equity;

import cn.com.duiba.api.bo.page.Page;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.goods.center.api.remoteservice.dto.equity.EquityGoodsRecordDto;
import cn.com.duiba.goods.center.api.remoteservice.dto.equity.EquityVerificationCountDto;
import cn.com.duiba.goods.center.api.request.equity.FindPageRequest;

import java.util.List;

/**
 * @program: goods-center-all
 * @description: 权益商品
 * @author: Simba
 * @create: 2019-07-09 16:16
 **/
@AdvancedFeignClient
public interface RemoteEquityGoodsRecordService {

    Long save(EquityGoodsRecordDto dto);

    int batchInsert(List<EquityGoodsRecordDto> equityGoodsRecordDtoList);

    int deleteById(Long id);

    int deleteBatchByIds(List<Long> ids);

    int deleteBatchByBatchId(Long batchId);

    int deleteBatchByEquityId(Long equityId);

    int updateById(EquityGoodsRecordDto dto);

    EquityGoodsRecordDto selectById(Long id);

    EquityGoodsRecordDto selectByCode(Long appId, String code);

    List<EquityGoodsRecordDto> selectByCodes(Long appId, List<String> codeList);

    List<EquityGoodsRecordDto> listByIds(List<Long> ids);

    List<String> selectExistCodeByCodes(Long appId, List<String> codeList);

    List<EquityVerificationCountDto> selectAllAndVerificationCountByEquityIds(List<Long> equityIds);

    Page<EquityGoodsRecordDto> findPageByConditions(FindPageRequest request);

    Long findPageCountByConditions(FindPageRequest request);

    Page<EquityGoodsRecordDto> findMerchantPageByConditions(FindPageRequest request);

    Long findMerchantPageCountByConditions(FindPageRequest request);

}

==> goods-center-api-2.8.77-sources.jar: cn/com/duiba/goods/center/api/remoteservice/equity/RemoteEquityGoodsRecordService.java <==
package cn.com.duiba.goods.center.api.remoteservice.equity;

import cn.com.duiba.api.bo.page.Page;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.goods.center.api.remoteservice.dto.equity.EquityGoodsRecordDto;
import cn.com.duiba.goods.center.api.remoteservice.dto.equity.EquityVerificationCountDto;
import cn.com.duiba.goods.center.api.request.equity.FindPageRequest;
import cn.com.duiba.goods.center.api.request.equity.GoodsRecordFindPageConditions;

import java.util.List;

/**
 * @program: goods-center-all
 * @description: 权益商品
 * @author: Simba
 * @create: 2019-07-09 16:16
 **/
@AdvancedFeignClient
public interface RemoteEquityGoodsRecordService {

    Long save(EquityGoodsRecordDto dto);

    int batchInsert(List<EquityGoodsRecordDto> equityGoodsRecordDtoList);

    int deleteById(Long id);

    int deleteBatchByIds(List<Long> ids);

    int deleteBatchByBatchId(Long batchId);

    int deleteBatchByEquityId(Long equityId);

    int updateById(EquityGoodsRecordDto dto);

    List<EquityGoodsRecordDto> listByConditionParam(GoodsRecordFindPageConditions goodsRecordFindPageConditions);

    EquityGoodsRecordDto selectById(Long id);

    EquityGoodsRecordDto selectByCode(Long appId, String code);

    List<EquityGoodsRecordDto> selectByCodes(Long appId, List<String> codeList);

    List<EquityGoodsRecordDto> listByIds(List<Long> ids);

    List<String> selectExistCodeByCodes(Long appId, List<String> codeList);

    List<EquityVerificationCountDto> selectAllAndVerificationCountByEquityIds(List<Long> equityIds);

    Page<EquityGoodsRecordDto> findPageByConditions(FindPageRequest request);

    Long findPageCountByConditions(FindPageRequest request);

    Page<EquityGoodsRecordDto> findMerchantPageByConditions(FindPageRequest request);

    Long findMerchantPageCountByConditions(FindPageRequest request);

    List<EquityGoodsRecordDto> listByAppIdAndCodes(Long appId, List<String> codes);

}
